use axum::{
    body::Body,
    http::Request,
    middleware::{self, Next},
    response::Response,
    routing::get,
    Router,
};
use http::Method;
use rand::seq::SliceRandom;
use std::net::SocketAddr;
use tower_http::cors::{Any, CorsLayer};
use tower_http::services::ServeDir;
use tracing::info;

#[shuttle_runtime::main]
async fn main() -> shuttle_axum::ShuttleAxum {
    let cors = CorsLayer::new()
        .allow_origin(Any) // Allow all origins; adjust as necessary
        .allow_methods(vec![Method::GET]) // Specify allowed methods
        .allow_headers(Any);

    let router = Router::new()
        .nest_service("/", ServeDir::new("frontend/dist"))
        .route("/word", get(word))
        .layer(middleware::from_fn(log_ip))
        .layer(cors);

    Ok(router.into())
}

async fn word() -> String {
    let mut rng = rand::thread_rng();
    WORDS.choose(&mut rng).unwrap().to_string()
}

async fn log_ip(req: Request<Body>, next: Next) -> Response {
    let ip = req
        .headers()
        .get("x-forwarded-for")
        .and_then(|hv| hv.to_str().ok())
        .or_else(|| {
            req.headers()
                .get("x-real-ip")
                .and_then(|hv| hv.to_str().ok())
        })
        .or_else(|| {
            req.headers()
                .get("cf-connecting-ip")
                .and_then(|hv| hv.to_str().ok())
        })
        .unwrap_or("Unknown");

    info!(PATH = req.uri().path().to_string(), IP = ip);

    next.run(req).await
}

static WORDS: &[&str; 5921] = &[
    "aalen", "Aales", "aalst", "aalte", "Aarau", "Aaron", "Aasee", "Aases", "Abart", "abbat",
    "Abbau", "Abbey", "abbog", "Abdul", "Abeba", "Abels", "Abend", "abgab", "Abgas", "abhob",
    "Abhub", "abkam", "ablas", "ablud", "Abort", "Abruf", "absah", "Absud", "abtat", "Abtei",
    "Abtes", "abtue", "abtun", "abtut", "Abuja", "Abweg", "abwog", "abzgl", "abzog", "Abzug",
    "Accra", "Achat", "Achim", "Achse", "achte", "Acker", "Acres", "Acryl", "Adams", "Addis",
    "Addon", "Adela", "adele", "adeln", "Adels", "adelt", "Adept", "Adern", "adieu", "Adler",
    "adlig", "Adlon", "Admin", "Adobe", "Adolf", "Adorf", "Adria", "adrig", "adult", "aerob",
    "Affen", "affig", "affin", "Affix", "Afros", "After", "Agame", "Agape", "Agave", "Agens",
    "Agent", "Agfas", "agile", "Agios", "Agnat", "Agnes", "Agora", "Agrar", "Aguti", "Ahaus",
    "Ahlen", "Ahmed", "ahmen", "Ahmet", "ahmst", "ahmte", "ahnde", "ahnen", "ahnst", "ahnte",
    "Ahorn", "Aidas", "Aioli", "Aires", "Akaba", "Akira", "Akkon", "Akkus", "Aktei", "Akten",
    "Aktes", "Aktie", "aktiv", "Aktor", "akute", "alaaf", "Alain", "Alarm", "Alaun", "Alban",
    "Albas", "Alben", "Albin", "Album", "Aldis", "Aleph", "alert", "Alete", "Alexa", "Algen",
    "Algin", "alias", "Alibi", "Alice", "Alien", "Alina", "Alkan", "Alkin", "Alkis", "Alkyl",
    "Allah", "Allee", "Allel", "allem", "allen", "aller", "alles", "Allod", "allwo", "Allyl",
    "Allys", "allzu", "Almas", "Almen", "Alois", "Alpen", "alpha", "alpin", "Alsen", "Altai",
    "Altan", "Altar", "altem", "alten", "alter", "altes", "Altis", "Alwin", "Alzey", "Amati",
    "Amber", "ambig", "Ambon", "Ambra", "Amida", "Amide", "Amids", "Amiga", "Amigo", "Amine",
    "Amins", "Amman", "Ammen", "Ammer", "Ammon", "Amors", "Amoun", "Ampel", "Amrum", "Amsel",
    "Amtes", "Amway", "anale", "Anbau", "anbei", "anbot", "Anden", "andin", "Andys", "angab",
    "Angel", "Anger", "Angie", "angle", "angst", "Angus", "anhat", "anhin", "anhob", "Anika",
    "Anime", "Anion", "Anita", "Anjas", "Anjou", "ankam", "Anker", "Ankes", "Ankum", "anlag",
    "anlog", "Anmut", "Annam", "Annan", "Annas", "Annes", "Annex", "Annie", "Anode", "Anruf",
    "ansah", "ansog", "antat", "antik", "Antje", "Anton", "antue", "antun", "antut", "Anwar",
    "anzog", "Anzug", "Aorta", "Aosta", "apart", "Apfel", "Apnoe", "Apoll", "Apple", "April",
    "Apsis", "Aquin", "Arals", "Arbon", "ArbZG", "Arche", "Arcor", "Arcus", "Areal", "Areas",
    "Arena", "Arend", "argem", "argen", "arger", "arges", "Argon", "Argot", "Argus", "Arial",
    "aride", "Ariel", "Arien", "Arier", "Aries", "Arius", "arkan", "Arkus", "Arles", "Armee",
    "armem", "armen", "armer", "armes", "Armin", "Armut", "Arndt", "Arnes", "Arnim", "Arnos",
    "Aroma", "Arosa", "Arpad", "Array", "Arsch", "Arsen", "arten", "artet", "artig", "Artus",
    "Aruba", "Arvid", "Asche", "ASCII", "Ascot", "ASEAN", "Asiat", "Asien", "Asket", "Aslan",
    "Aspen", "Aspik", "Assad", "Assam", "Assel", "Assen", "Asses", "Asset", "Aster", "Astes",
    "Astor", "Astra", "Astro", "Asyle", "Asyls", "Atari", "Atems", "Athen", "Athos", "Atlas",
    "atmen", "atmet", "Atoll", "Atome", "Atoms", "Attac", "Audio", "Audis", "Audit", "Augen",
    "Auges", "Augur", "aural", "Aurel", "Aurum", "Autan", "Autor", "Autos", "Autun", "auwei",
    "Auxin", "avers", "Aviso", "Avivs", "Award", "Axels", "axial", "Axiom", "Axone", "Axons",
    "Ayran", "Aznar", "Azubi", "Baals", "Babel", "Babsi", "Babys", "Bache", "Bachs", "backe",
    "backt", "Bacon", "baden", "Bader", "Bades", "badet", "BaFin", "Bagel", "Bahai", "bahne",
    "bahnt", "Bahre", "Baken", "Bakus", "balge", "Balgs", "balgt", "Balis", "Balje", "balle",
    "Balls", "ballt", "Balou", "Balsa", "Balte", "Balve", "balze", "balzt", "Bambi", "banal",
    "Banat", "Bande", "Bands", "bange", "bangt", "Banjo", "banne", "Banns", "bannt", "Bantu",
    "Barbe", "Barde", "barem", "baren", "barer", "bares", "bargt", "Baris", "Barke", "Baron",
    "Barry", "barst", "Barts", "Baryt", "basal", "Basar", "Basel", "Basen", "Basic", "Basil",
    "Basis", "Baske", "Basra", "Basso", "basta", "Basti", "Batch", "baten", "batet", "Batik",
    "Bator", "batst", "Bauch", "bauen", "Bauer", "Baues", "BauGB", "Baums", "baust", "baute",
    "Bayer", "Bayes", "BayWa", "Bazar", "Bazis", "BBesG", "Beach", "beame", "beamt", "Beata",
    "Beate", "Beats", "Bebel", "beben", "Bebop", "Bebra", "bebst", "bebte", "Becks", "Becky",
    "beeil", "beeng", "Beere", "Beete", "Beets", "begab", "begib", "behob", "Behuf", "beide",
    "beige", "Beile", "Beils", "Beine", "Beins", "Beisl", "beize", "beizt", "bekam", "Belag",
    "Belas", "Beleg", "Bella", "belle", "Bello", "Bells", "bellt", "belog", "belud", "Bemme",
    "Bengt", "Benin", "Benni", "Benno", "Benns", "Benny", "Beppo", "berge", "Bergs", "bergt",
    "Berit", "Bernd", "Berns", "Berta", "Berti", "Berts", "Beruf", "besah", "Besan", "Besen",
    "beste", "Betel", "beten", "Beter", "betet", "Beton", "bette", "Betti", "Betts", "Betty",
    "beuge", "beugt", "beule", "beute", "Beuth", "Beuys", "bevor", "beweg", "bewog", "bezog",
    "Bezug", "BGHSt", "Bibel", "Biber", "Bidet", "biege", "biegt", "Biene", "Biere", "Biers",
    "Biese", "Biest", "biete", "Bihar", "Biker", "Bikes", "Bilch", "bilde", "Bilds", "Bilge",
    "Bills", "Billy", "Bimbo", "bimse", "bimst", "binde", "Bingo", "Binom", "Binse", "biped",
    "birgt", "Birke", "Birma", "Birne", "birst", "Bisam", "Bisky", "Bison", "Bisse", "bisst",
    "bitte", "Biwak", "Bizet", "Blair", "Blake", "blank", "blase", "blass", "blast", "Blatt",
    "blaue", "Blech", "bleib", "Bleis", "blich", "Blick", "blieb", "blies", "Blimp", "blind",
    "Blini", "Blitz", "Bloch", "Block", "Blogs", "blond", "Blues", "Bluff", "Blume", "Bluse",
    "blute", "Bluts", "BMVBW", "Board", "Bobby", "bocke", "Bocks", "bockt", "Boden", "Bodos",
    "Bodys", "bogen", "Bogey", "bogig", "bogst", "Bohei", "Bohle", "Bohne", "bohre", "Bohrs",
    "bohrt", "Bojen", "Bolle", "Bolte", "bolze", "bolzt", "Bombe", "Bonds", "Bongo", "Bonns",
    "Bonus", "Bonze", "Boole", "boome", "Booms", "boomt", "boote", "Boots", "Borax", "Borde",
    "Bords", "borge", "borgt", "Boris", "Borke", "Borna", "Borns", "Borte", "Bosch", "Bosco",
    "Boson", "Bosse", "boten", "botet", "Botin", "Botox", "botst", "Boule", "bovin", "Bowie",
    "Bowle", "boxen", "Boxer", "boxte", "Bozen", "BPatG", "brach", "Braga", "Brand", "Brass",
    "brate", "braue", "braun", "Braus", "braut", "brave", "bravo", "Break", "Breda", "Brehm",
    "Breie", "Breis", "breit", "brenn", "Brent", "Brenz", "Brest", "Brett", "Brevi", "Brian",
    "brich", "Brief", "Bries", "briet", "Brigg", "bring", "Brise", "Brite", "Brock", "Broms",
    "Bronx", "Brote", "Brown", "Bruce", "Bruch", "Brugg", "Bruni", "Bruno", "Brust", "Bryan",
    "Buben", "Bubis", "buche", "Buchs", "bucht", "Bucks", "Buddy", "Buden", "Buffo", "Buges",
    "Buggy", "Buhei", "buhen", "buhle", "buhlt", "Buhne", "buhst", "buhte", "Buick", "buken",
    "bukst", "Bulle", "Bulli", "Bully", "bumse", "bumst", "Bunde", "Bunds", "Bunny", "bunte",
    "Burda", "Buren", "Burka", "Burma", "Bursa", "Burse", "Busch", "Busen", "Bushs", "Busse",
    "Bussi", "Butan", "Butch", "Butze", "Byron", "Bytes", "cache", "cacht", "Caddy", "Cadiz",
    "Calws", "campe", "Camps", "campt", "Camus", "Canna", "Canon", "Capes", "Capri", "Cards",
    "Carey", "Cargo", "Carla", "Carlo", "Carls", "Carol", "Carta", "Cathy", "Catos", "causa",
    "CCITT", "CeBIT", "Celan", "Cella", "Celle", "Celli", "Cello", "Cents", "Ceran", "Ceres",
    "Cerny", "Champ", "Chaos", "Chaot", "Chart", "Chats", "Cheat", "check", "Chefs", "Chemo",
    "chice", "Chile", "Chili", "China", "Chips", "Chlor", "Choke", "Chors", "Chose", "Chris",
    "Chrom", "Chuck", "Churs", "Cidre", "Cinch", "Cindy", "circa", "Cisco", "Citys", "Civil",
    "Claim", "Clans", "Clara", "Clark", "Claus", "clean", "Clint", "Clips", "Clogs", "Clone",
    "Cloud", "Clown", "Clubs", "Cluny", "Clyde", "Coach", "coate", "Coats", "Cobol", "Codec",
    "Codes", "Codex", "Codon", "Colas", "Colin", "Colts", "Combo", "Comic", "Conny", "coole",
    "Corps", "Corsa", "Corso", "Costa", "Cotta", "Couch", "Count", "Coups", "Court", "Cover",
    "Crack", "Craig", "Crash", "Crawl", "crazy", "Credo", "Creek", "creme", "cremt", "Crews",
    "Crime", "Cross", "Curie", "Curry", "Cyber", "dabei", "Dachs", "Daddy", "dahat", "daher",
    "dahin", "Daisy", "Dakar", "Daker", "dalag", "Dalai", "Dalis", "dalli", "Damen", "damit",
    "Damms", "Dampf", "Danas", "Dandy", "danke", "Danks", "dankt", "Danny", "Dante", "daran",
    "darbe", "darbt", "darin", "Dario", "Darms", "darob", "Darre", "Darts", "darum", "Datei",
    "Daten", "Dates", "DATEV", "Datex", "Dativ", "Datum", "Daube", "Dauer", "Daune", "David",
    "Davis", "davon", "davor", "Davos", "deale", "Deals", "dealt", "Deans", "debil", "Debit",
    "decke", "Decks", "deckt", "Defoe", "Degen", "dehne", "dehnt", "Deich", "deine", "deins",
    "Dekan", "Dekor", "Dekra", "Delft", "Delhi", "Delia", "Delir", "delle", "dellt", "delta",
    "Demos", "Demut", "Denar", "denen", "Denim", "Denis", "denke", "denkt", "Depot", "Depps",
    "derbe", "Derby", "Derek", "deren", "derer", "desto", "deute", "Deutz", "Devon", "devot",
    "Dewey", "DGzRS", "Dhabi", "Dhaka", "Diana", "Diane", "dicht", "dicke", "Diebe", "Diebs",
    "Diego", "Diele", "diene", "dient", "diese", "Dietz", "Dijon", "Dildo", "Dille", "Dills",
    "Dimas", "dimme", "dimmt", "Dinar", "Diner", "dinge", "Dingo", "Dings", "Dinos", "Diode",
    "Dipol", "dippe", "dippt", "Direx", "Dirks", "Dirne", "Disco", "Discs", "Disko", "Disks",
    "Dispo", "disse", "disst", "Divas", "Diven", "Diwan", "DJane", "Docht", "docke", "Docks",
    "dockt", "Dodge", "Dodos", "Dogen", "Dogge", "Doggy", "Dogma", "Dohle", "Dolby", "dolce",
    "Dolch", "Dolde", "dolle", "Dolly", "Domen", "Domes", "Donau", "Donna", "Donny", "Donut",
    "doofe", "Doofi", "Doors", "dopen", "Doper", "Doras", "Dorer", "Dorfe", "Dorfs", "Doria",
    "Doris", "Dorne", "Dorns", "dorre", "dorrt", "Dosen", "Dosis", "Dover", "Doyen", "Doyle",
    "DPolG", "Draht", "Drake", "drall", "Drama", "drang", "drauf", "draus", "Dreck", "drehe",
    "Drehs", "dreht", "drein", "Dress", "Drift", "Drill", "Drink", "dritt", "Drive", "Droge",
    "drohe", "droht", "Drops", "druck", "Drums", "Druse", "DSchG", "DSLRs", "duale", "Dubai",
    "dubio", "ducke", "duckt", "Duden", "dudle", "Duell", "Duett", "dufte", "Dufts", "Dukat",
    "dulde", "Dumas", "dumme", "Dummy", "dumpf", "Dungs", "Dunja", "Dunst", "Duplo", "durch",
    "Durst", "Dusel", "Dutte", "Dutts", "duzen", "duzte", "Dylan", "Earls", "Earth", "ebben",
    "ebbte", "ebene", "Ebern", "Ebers", "Ebert", "ebnen", "Ebner", "ebnet", "Ebola", "eBook",
    "Echos", "Echse", "echte", "ecken", "eckig", "eckst", "eckte", "Edams", "Eddas", "Eddie",
    "Edeka", "Edens", "Eders", "Edgar", "Edies", "Edikt", "Edith", "edlem", "edlen", "edler",
    "edles", "Ednas", "Edukt", "Edwin", "Efeus", "Effet", "Egeln", "Egels", "Eggen", "eGmbH",
    "Egons", "ehern", "ehren", "ehrst", "ehrte", "Eiben", "eiche", "eicht", "Eicke", "Eidam",
    "Eiden", "Eider", "Eides", "eiere", "eiern", "eiert", "Eifel", "Eifer", "eigen", "Eiger",
    "eigne", "Eilat", "eilen", "eilig", "eilst", "eilte", "Eimer", "Einar", "einem", "einen",
    "einer", "eines", "einig", "einst", "einte", "Eisen", "Eises", "eisig", "eitel", "Eiter",
    "eitle", "eitre", "ekele", "ekeln", "Ekels", "ekelt", "Eklat", "eklig", "ektop", "Ekzem",
    "Elans", "Elath", "Elche", "Elchs", "Elena", "elend", "Eleve", "Elfen", "Elfer", "elfte",
    "Elgar", "Elias", "Elina", "Eliot", "Elisa", "Elise", "Elite", "Eliza", "Elkes", "Ellen",
    "Eller", "Ellis", "Elmar", "Eloge", "Elsas", "Elses", "Elspe", "Elvis", "Emden", "Emder",
    "Emile", "Emils", "Emily", "Emire", "Emirs", "Emmas", "Emmys", "Emnid", "Emoji", "empor",
    "Emser", "emsig", "enden", "Endes", "endet", "Engel", "engem", "engen", "enger", "enges",
    "engst", "engte", "Enkel", "Ennui", "enorm", "Enten", "Enter", "Enzym", "Eplax", "EPROM",
    "Epson", "erbat", "erben", "Erbes", "Erbin", "erbot", "Erbse", "erbst", "erbte", "Erdal",
    "erden", "erdet", "erdig", "ergab", "ergib", "erhob", "Erich", "Erics", "Erika", "Eriks",
    "Erker", "erkor", "erlag", "Erlen", "Ernas", "Ernie", "ernst", "ernte", "Erpel", "Error",
    "erste", "Erwin", "erwog", "Erzen", "Erzes", "erzog", "Esaus", "Esche", "Eseln", "Esels",
    "Espen", "Essay", "essen", "Esser", "Essex", "Essig", "Essos", "Esten", "Ester", "Estin",
    "Etage", "Etats", "Ethan", "Ether", "Ethik", "Ethin", "Ethos", "Etons", "Etsch", "Ettal",
    "Etuis", "etwas", "Etzel", "Eugen", "Eulen", "Euler", "Eupen", "eurem", "euren", "eurer",
    "eures", "Euros", "Euter", "Eutin", "Event", "Evita", "Ewald", "ewige", "exakt", "Excel",
    "Exile", "Exils", "Expat", "Exter", "extra", "Exxon", "Eylau", "Fabel", "Faber", "Fabio",
    "fache", "Fachs", "facht", "facto", "fadem", "faden", "fader", "fades", "fahle", "Fahne",
    "fahre", "fahrt", "faire", "Fakes", "Fakir", "Fakts", "falbe", "Falco", "Falke", "Falko",
    "falle", "falls", "fallt", "falte", "falze", "falzt", "FamFG", "famos", "Fanal", "fange",
    "Fango", "Fangs", "fangt", "Fanni", "Fanny", "Fanta", "Farad", "Farbe", "Farce", "Farne",
    "Farns", "Farsi", "Fasan", "Faser", "Fasos", "fasse", "fasst", "faste", "fatal", "Fatum",
    "Fatwa", "faule", "fault", "Fauna", "Faune", "Fauns", "Faust", "faxen", "Faxes", "faxte",
    "Fazit", "Feder", "FedEx", "fegen", "Feger", "fegst", "fegte", "Fehde", "fehle", "fehlt",
    "Feier", "feige", "feile", "feilt", "feind", "feine", "feist", "feixe", "feixt", "Felde",
    "Felds", "Felge", "felin", "Felix", "Felle", "Fells", "Femen", "Femur", "Ferdi", "Ferme",
    "Fermi", "ferne", "Ferse", "fesch", "feste", "Fests", "fetal", "Feten", "fette", "Fetus",
    "fetze", "fetzt", "Feuer", "Fezen", "Fiats", "Fibel", "Fiber", "ficht", "ficke", "Ficks",
    "fickt", "Ficus", "fidel", "fiele", "fielt", "fiepe", "fiept", "fiese", "Fiffi", "Fifis",
    "Fight", "Figur", "Files", "Filet", "filme", "Films", "filmt", "Filou", "Filze", "filzt",
    "final", "Finca", "finde", "finge", "fingt", "finit", "Finne", "Finns", "Finte", "Fiona",
    "Firma", "First", "Fisch", "fitte", "fixem", "fixen", "fixer", "fixes", "fixte", "Fixum",
    "Fjord", "flach", "Flair", "Flame", "Flash", "Flats", "flaue", "Flaum", "flaut", "Fleck",
    "flehe", "fleht", "Fleur", "Flick", "flieg", "flieh", "flink", "Flint", "Flips", "Flirt",
    "flogt", "Flohs", "floht", "Flops", "Flora", "floss", "flott", "Flows", "Floyd", "Fluch",
    "Fluge", "flugs", "fluid", "Fluke", "Fluor", "Flure", "Flurs", "Fluse", "Flush", "Fluss",
    "flute", "Flyer", "focht", "Focus", "fokal", "Fokus", "folge", "folgt", "Folie", "Folio",
    "Folks", "Fonds", "Fonts", "foppe", "foppt", "Force", "Fords", "Foren", "Forex", "Forke",
    "Forks", "forma", "forme", "formt", "Forsa", "Forst", "forte", "Forts", "Forum", "Fossa",
    "Fotos", "Fotze", "Fouls", "Foyer", "Frack", "frage", "fragt", "Frame", "Franc", "frank",
    "Franz", "Fratz", "Freak", "frech", "Freds", "freie", "freit", "fremd", "Freud", "freue",
    "freut", "Frida", "Fries", "Friso", "friss", "Frist", "Fritz", "frohe", "fromm", "Front",
    "frort", "Frost", "Frust", "Fuchs", "Fuder", "Fuffi", "fugen", "fugst", "fugte", "Fuhre",
    "fuhrt", "Fulda", "Funde", "Fundi", "Funds", "funke", "Funks", "funkt", "funky", "funzt",
    "Furie", "Furor", "furze", "furzt", "Fusel", "Futon", "Futur", "fuzzy", "Gabel", "gaben",
    "Gabis", "gable", "gabst", "Gabun", "Gabys", "gaffe", "gafft", "Gagen", "Gaias", "Gaius",
    "Galan", "Galen", "Galle", "Gallo", "Gamba", "Gambe", "Gamer", "Games", "Gamet", "gamma",
    "Gange", "Gangs", "Ganja", "ganze", "Garbe", "Garbo", "Garde", "garem", "garen", "garer",
    "gares", "Garne", "garni", "Garns", "Garry", "garte", "Gasen", "Gases", "Gasse", "Gassi",
    "Gasts", "Gates", "Gatte", "Gatts", "Gaube", "Gauck", "Gaudi", "Gauen", "Gauls", "Gazas",
    "Gazen", "GBits", "GByte", "gebar", "geben", "Geber", "Gebet", "gebot", "Gecko", "Geest",
    "gegen", "gehab", "gehen", "Geher", "gehst", "Geier", "geige", "geigt", "geile", "geilt",
    "Geist", "geize", "geizt", "gelbe", "Gelde", "Gelds", "Gelee", "gelle", "gellt", "gelte",
    "Gemme", "genas", "genau", "Genen", "Genfs", "Genie", "Genom", "Genre", "Gents", "Genua",
    "genug", "Genus", "Georg", "Geras", "gerbe", "gerbt", "Gerda", "Gerds", "gerne", "Geros",
    "Gerte", "Gerti", "Gerts", "Gesas", "Geste", "getan", "Getto", "Getty", "Getue", "gGmbH",
    "Ghali", "Ghana", "gibst", "Gicht", "giere", "giert", "gifte", "Gifts", "gilbt", "Gilde",
    "Ginas", "ginge", "gingt", "Girls", "Giros", "Gitta", "Gitte", "Gitti", "Gizeh", "Glanz",
    "glatt", "glaub", "Gleis", "Glenn", "glich", "Glied", "glitt", "Globe", "Glock", "glomm",
    "glotz", "gluck", "Gluon", "Gmail", "GmbHs", "gnade", "Gneis", "Gnome", "Gnoms", "Godot",
    "Goghs", "Gojim", "Golan", "Golda", "Golde", "Golds", "Golem", "golfe", "Golfs", "golft",
    "Gomez", "Gongs", "Goofy", "Gorch", "goren", "Gorki", "Gosse", "gosst", "Goten", "Gotha",
    "Gotik", "Gotin", "Gouda", "Gould", "Goyas", "grabe", "Grabs", "grabt", "Grace", "Grade",
    "Grads", "Grals", "Gramm", "Grams", "Grand", "Graph", "grase", "Grass", "grast", "Grate",
    "Grats", "graue", "Graus", "graut", "Greco", "Green", "greif", "Greis", "Greiz", "grell",
    "Greta", "Grete", "griff", "grill", "Grimm", "Grind", "grins", "Grips", "grobe", "Grogs",
    "Groll", "Group", "Grube", "grubt", "Gruft", "Gruga", "Grund", "Guano", "Guave", "Gucci",
    "gucke", "guckt", "Guide", "Guido", "Gulag", "Gully", "Gummi", "Gundi", "Gunst", "Guppy",
    "gurke", "gurkt", "gurrt", "gurte", "Gurus", "Gustl", "Gusto", "gutem", "guten", "guter",
    "gutes", "Gyros", "Gysis", "haare", "Haars", "haart", "haben", "habet", "habil", "Habit",
    "hacke", "Hacks", "hackt", "Hader", "Hades", "hadre", "Hafen", "Hafer", "Haffs", "hafte",
    "Hagel", "Hagen", "hager", "Hagia", "hagle", "Hahns", "Haien", "Haies", "Haifa", "Haiku",
    "Haine", "Hains", "Haiti", "haken", "hakig", "hakst", "hakte", "halbe", "Halde", "halft",
    "Halit", "halle", "hallo", "Halls", "hallt", "Halma", "Halme", "Halms", "Halon", "halse",
    "halte", "Hamam", "Hamas", "Hamms", "Hanau", "Handy", "Hanfs", "Hangs", "Hanna", "Hanne",
    "Hanni", "Hanno", "Hanns", "Hanoi", "Hansa", "Hanse", "Hansi", "Hapag", "happy", "Hardt",
    "Hardy", "Harem", "Harfe", "harke", "harkt", "Harns", "harre", "Harro", "harrt", "Harry",
    "harte", "Hartz", "harze", "harzt", "Hasch", "Hasel", "Hasen", "hasse", "Hasso", "hasst",
    "haste", "hatte", "Haube", "hauch", "hauen", "Hauer", "Hauff", "Hauke", "Haupt", "hause",
    "haust", "haute", "Havel", "Haxen", "Haydn", "Hayes", "Heavy", "Hebel", "heben", "Heber",
    "heble", "hebst", "Hecht", "hecke", "Hecks", "heckt", "Hedda", "Hedis", "Heere", "Heers",
    "Hefen", "hefte", "Hefts", "Hegau", "Hegel", "hegen", "Heger", "hegst", "hegte", "hehle",
    "hehlt", "hehre", "Heide", "Heidi", "Heike", "Heiko", "heile", "Heils", "heilt", "Heime",
    "Heims", "Heine", "Heini", "Heino", "Heins", "Heinz", "Heise", "heize", "heizt", "helau",
    "Helds", "Helen", "helfe", "helft", "Helga", "Helge", "Helis", "Helix", "Hella", "helle",
    "hellt", "Helma", "Helme", "Helms", "Helot", "Hemds", "Hemer", "hemme", "hemmt", "Hendl",
    "Henna", "Henne", "Henni", "Henri", "Henry", "Henze", "herab", "heran", "Heras", "herbe",
    "Herde", "Herds", "Herme", "Herne", "Heroe", "Heros", "Herrn", "Herta", "Hertz", "herum",
    "herze", "Herzl", "herzt", "herzu", "Hesse", "hetze", "hetzt", "heuer", "heule", "heult",
    "Heuss", "heute", "Hexan", "hexen", "Hexer", "hexte", "Heyne", "hicks", "hiebe", "hielt",
    "hieve", "hievt", "Hilda", "Hilde", "Hilfe", "hilft", "Hille", "Hills", "hinab", "hinan",
    "Hindi", "Hindu", "hinge", "hingt", "hinke", "hinkt", "hinzu", "Hiobs", "hippe", "Hippo",
    "Hirne", "Hirni", "Hirns", "Hirse", "Hirte", "hisse", "hisst", "Hitze", "Hiwis", "Hobby",
    "Hobel", "hoben", "hoble", "hobst", "Hochs", "hocke", "hockt", "Hoden", "Hofer", "Hofes",
    "hoffe", "hofft", "hohem", "hohen", "hoher", "hohes", "hohle", "Hohns", "holde", "holen",
    "holla", "Holle", "Holly", "Holme", "Holms", "holst", "holte", "holzt", "Homer", "Homos",
    "Honda", "Honey", "Honig", "Hoods", "Hoorn", "hopsa", "hopse", "hopst", "Horaz", "horch",
    "Horde", "Horen", "Horns", "Horst", "horte", "Horus", "Hosea", "Hosen", "hoste", "Hosts",
    "Hotel", "HTTPS", "Huber", "Hubes", "Hucke", "Hufen", "Hufes", "Hugos", "Huhns", "Hulks",
    "human", "Humes", "humid", "Humor", "humos", "Humus", "Hunan", "Hunde", "Hunds", "Hunne",
    "Hunni", "hupen", "hupst", "hupte", "huren", "hurra", "hurst", "hurte", "Husar", "husch",
    "Husky", "hussa", "Husse", "huste", "Husum", "Hutes", "Hutus", "Hydra", "Hydro", "Hymen",
    "Hymne", "Hypes", "Hyphe", "Ibiza", "Ibsen", "ICANN", "Icons", "Idaho", "ideal", "Ideen",
    "Idiom", "Idiot", "Idole", "Idols", "Iduna", "Idyll", "igeln", "Igels", "igelt", "igitt",
    "Iglus", "Ignaz", "Igors", "Ihlow", "ihnen", "ihrem", "ihren", "ihrer", "ihres", "Ikone",
    "Ileus", "Ilias", "Ilium", "Iljas", "Ilkas", "Iller", "Ilona", "Ilses", "Ilten", "Iltis",
    "Image", "Imame", "Imams", "Imker", "imkre", "Immen", "immer", "immun", "Imola", "impfe",
    "impft", "Inbus", "indem", "Inder", "indes", "Index", "Indie", "Indik", "Indio", "Indiz",
    "Indus", "inert", "infam", "Infix", "Infos", "Inges", "Ingos", "Inkas", "Inlay", "innen",
    "innig", "Input", "Insas", "Insel", "Intel", "intim", "Intro", "intus", "Inuit", "Iodat",
    "Iodid", "Ionen", "Iowas", "iPads", "iPods", "Iraks", "Irans", "irden", "Irene", "Irina",
    "Irmas", "irrem", "irren", "irrer", "irres", "irrig", "irrst", "irrte", "Isaac", "Isaak",
    "Ische", "Ischl", "Islam", "Issos", "Issue", "Issum", "Italo", "Items", "Ivans", "Iveco",
    "Iwans", "Iwrit", "Izmir", "Jacht", "Jacke", "Jacks", "Jacob", "Jaffa", "jagen", "Jagos",
    "jagst", "jagte", "Jahns", "Jahre", "Jahrs", "Jahwe", "Jakob", "Jalon", "Jalta", "James",
    "Jamie", "jammt", "Janas", "Jandl", "Janet", "Janus", "Japan", "japse", "japst", "Jason",
    "jaule", "jault", "Jause", "Javas", "Jeans", "jecke", "jedem", "jeden", "jeder", "jedes",
    "Jeeps", "jeher", "Jemen", "Jenas", "jenem", "jenen", "jener", "jenes", "Jenna", "Jenni",
    "Jenny", "Jerez", "Jerry", "Jerzy", "Jesse", "Jessy", "Jesus", "Jeton", "jette", "jetzt",
    "Jever", "Jills", "Jimmy", "jobbe", "jobbt", "Jobst", "Joche", "Jochs", "Jodat", "Jodid",
    "Joels", "Joeys", "jogge", "joggt", "Jogis", "johle", "johlt", "Johns", "Joint", "Jojos",
    "Joker", "Jokus", "Jolle", "Jolly", "Jonas", "Jones", "Jonny", "Joppe", "Jorge", "Josef",
    "Josua", "Joule", "Joyce", "Juana", "Juans", "Jubel", "juble", "jucke", "juckt", "Judas",
    "Juden", "Judiz", "Judos", "Juist", "Julei", "Jules", "Julia", "Julie", "Julio", "Julis",
    "Jumbo", "Jumps", "junge", "Jungs", "Junis", "Junos", "Junta", "Jupps", "Juras", "Jurek",
    "Jurij", "Juris", "Juror", "Jurte", "Jurys", "Jusos", "Jutta", "Juwel", "juxen", "Juxes",
    "juxte", "Kaaba", "Kabel", "Kabis", "kable", "Kabul", "kacke", "kackt", "Kader", "Kadis",
    "Kaffs", "Kafka", "kahle", "Kahns", "Kains", "Kairo", "Kajak", "Kajal", "Kakao", "Kakis",
    "kalbe", "Kalbs", "kalbt", "Kaleb", "Kalif", "Kalis", "kalke", "Kalks", "Kalle", "Kalme",
    "kalte", "Kamee", "Kamel", "kamen", "Kamin", "Kamms", "Kampf", "kamst", "Kanal", "Kanin",
    "Kanne", "Kanon", "kante", "Kants", "Kanus", "Kapee", "Kaper", "Kapok", "Kapos", "kappa",
    "kappe", "kappt", "Karat", "Karde", "Karel", "Karen", "karge", "Karin", "Karla", "Karls",
    "Karma", "Karol", "Karos", "karre", "karrt", "Karst", "Karte", "Kasan", "Kasel", "Kasko",
    "Kasse", "Kaste", "Kasus", "Katar", "Katen", "Kater", "Kathi", "Kathy", "Katia", "Katie",
    "Katis", "Katja", "Katze", "kauen", "kaufe", "Kaufs", "kauft", "Kauri", "kaust", "kaute",
    "KBaud", "KByte", "Kebab", "kecke", "Kefir", "kegel", "kegle", "Kehle", "kehre", "kehrt",
    "keife", "keift", "keile", "Keils", "keilt", "keime", "Keims", "keimt", "keine", "keins",
    "Keith", "Kekse", "Kelch", "Kelim", "Kelle", "Kelly", "Kelte", "Kemal", "Kenia", "kenne",
    "kennt", "Kenny", "Kents", "kerbe", "kerbt", "Kerle", "Kerls", "Kerne", "Kerns", "Kerub",
    "Kerze", "kesse", "kette", "keuch", "keule", "Kevin", "khaki", "Khane", "Khans", "Khmer",
    "kicke", "Kicks", "kickt", "Kiele", "Kiels", "Kieme", "Kiens", "Kiepe", "Kiese", "Kiews",
    "kiffe", "kifft", "kille", "killt", "Kilos", "Kilts", "Kimme", "Kindl", "Kinds", "Kings",
    "Kinne", "Kinns", "Kinos", "Kiosk", "Kioto", "Kiowa", "Kippa", "kippe", "kippt", "Kiras",
    "Kirch", "Kirow", "kirre", "Kiste", "Kitas", "kitte", "Kitts", "Kitty", "Kitze", "Kiwis",
    "kkStB", "klack", "klage", "klagt", "klamm", "klang", "Klans", "klapp", "Klaps", "Klara",
    "klare", "klaro", "klart", "klaue", "Klaus", "klaut", "klebe", "klebt", "Klees", "Kleid",
    "Kleie", "klein", "klemm", "Klett", "Kleve", "klick", "Kliff", "Klima", "Klimt", "klipp",
    "klirr", "klomm", "klone", "Klons", "klont", "klopf", "Klops", "Klotz", "Klubs", "Kluft",
    "kluge", "klump", "Knabe", "knack", "knall", "knapp", "knarr", "Knast", "Knauf", "Knaur",
    "kneif", "knete", "Knick", "knien", "Knies", "kniet", "kniff", "knips", "Knofi", "Knopf",
    "Knorr", "knote", "knuff", "knurr", "Knust", "Knute", "Knuts", "Koala", "Kobra", "koche",
    "Kochs", "kocht", "Kodak", "Kodes", "Kodex", "Kogge", "Kohle", "Kohls", "Kojen", "Kokon",
    "Kokos", "kokse", "kokst", "Kolbe", "Kolik", "Kolja", "Kolon", "Komas", "Kombi", "Komet",
    "Komik", "Komma", "komme", "kommt", "Kongo", "Konto", "Konus", "Kopfe", "Kopfs", "Kopie",
    "Kopte", "Koran", "Korbs", "Korea", "Korfu", "Korns", "Korps", "Korse", "Korso", "korst",
    "Kosak", "kosen", "koste", "Kotau", "koten", "kotze", "kotzt", "KPdSU", "Kraal", "Krach",
    "Krads", "kraft", "Krain", "Krake", "Krale", "krame", "Krams", "kramt", "krank", "Krans",
    "Kranz", "Krapp", "krass", "kratz", "Kraul", "kraus", "Kraut", "Krebs", "Kredo", "Kreis",
    "Kreme", "Kreml", "Krems", "Krenz", "Krepp", "Kreta", "kreuz", "krieg", "Krill", "Krimi",
    "Kripo", "Krise", "kroch", "Kroko", "Krone", "Kropf", "kross", "krude", "Krugs", "Kruke",
    "Krull", "Krume", "krumm", "Krupp", "Kruse", "Kuala", "Kubas", "Kuben", "Kubus", "Kufen",
    "Kugel", "kugle", "Kuhle", "Kuhns", "Kulis", "Kulte", "Kults", "Kumin", "Kumys", "Kunde",
    "Kunos", "Kunst", "Kunze", "Kupee", "Kupon", "Kuppe", "Kurde", "Kuren", "Kurie", "Kurse",
    "Kursk", "kurst", "Kurth", "Kurts", "kurve", "kurvt", "kurze", "kusch", "Kusel", "kutan",
    "Kutte", "Kyoto", "Kyrie", "Kyros", "Laach", "Label", "laben", "labil", "Labor", "labst",
    "labte", "lache", "Lachs", "lacht", "Lacke", "Lacks", "laden", "Lader", "ladet", "Ladys",
    "laffe", "lagen", "Lager", "Lagos", "lagst", "Lahar", "lahme", "lahmt", "Lahti", "Laibe",
    "Laibs", "Laich", "Laien", "Laika", "Laila", "Lakai", "Laken", "lalle", "lallt", "Lamas",
    "Lamee", "Lamms", "Lampe", "lande", "Lands", "lange", "langt", "Lanka", "Lanze", "Laote",
    "Lappe", "Laras", "Larry", "Larve", "lasch", "lasen", "Laser", "Lassa", "lasse", "Lasso",
    "lasst", "laste", "Lasur", "Latex", "LaTeX", "Latte", "latze", "latzt", "Laube", "Laubs",
    "Lauch", "Lauda", "laude", "lauem", "lauen", "lauer", "laues", "laufe", "Laufs", "lauft",
    "lauge", "laugt", "Laune", "Laura", "lause", "laust", "laute", "Lauts", "laxem", "laxen",
    "laxer", "laxes", "LBauO", "Leaks", "Lears", "lease", "least", "leben", "Leber", "lebst",
    "lebte", "Lebus", "Lecce", "Lechs", "lecke", "Lecks", "leckt", "Leder", "ledig", "Leeds",
    "leere", "leert", "Lefze", "legal", "Legat", "legen", "leger", "legst", "legte", "Lehen",
    "Lehme", "Lehms", "lehne", "lehnt", "lehre", "lehrt", "Leibe", "Leibs", "leibt", "Leica",
    "leide", "Leids", "Leier", "leihe", "leiht", "Leila", "leime", "leimt", "Leine", "Leins",
    "leise", "leite", "Leitz", "Lemgo", "Lemma", "Lemon", "Lemur", "Lenas", "Lenau", "Lende",
    "Lenin", "Lenis", "lenke", "lenkt", "Lenny", "Lenze", "Leone", "Leons", "Lepra", "lerne",
    "lernt", "Leroy", "Lesbe", "lesen", "Leser", "letal", "Lette", "Letzt", "Leuna", "Leute",
    "Level", "Levis", "Lewis", "Lexem", "Lexer", "Lexik", "Lexis", "Lexus", "Leyla", "Lhasa",
    "Liane", "licht", "LiDAR", "Lider", "Lides", "Lidos", "liebe", "liebt", "Lieds", "liefe",
    "lieft", "liege", "liegt", "lieht", "Liese", "Liesl", "liest", "lifte", "Lifts", "Ligen",
    "light", "Likes", "Lilie", "Lilis", "Lille", "Lilli", "Lilly", "Lilys", "Limas", "Limbo",
    "Limes", "Limit", "Limos", "Linda", "linde", "Lindt", "Linie", "linke", "links", "linkt",
    "Linon", "linse", "Linth", "Linum", "Linus", "Linux", "Lions", "Lipid", "Lippe", "Lisas",
    "Lissy", "liste", "Liszt", "Liter", "litte", "Litze", "Liven", "Livia", "Lloyd", "Lobby",
    "loben", "Lobes", "lobst", "lobte", "loche", "Lochs", "locht", "locke", "lockt", "Loden",
    "Lodge", "lodre", "Lofts", "logen", "logge", "loggt", "Logik", "Login", "Logis", "Logos",
    "logst", "Lohen", "lohne", "Lohns", "lohnt", "Loipe", "Loire", "lokal", "Lokus", "Lolli",
    "Looks", "Lopez", "Lords", "Loren", "Lores", "losem", "losen", "loser", "loses", "loste",
    "loten", "Lotes", "lotet", "Lotos", "lotse", "lotst", "Lotta", "Lotte", "Lotti", "Lotto",
    "Lotus", "Louis", "Lover", "loyal", "Lucas", "Lucca", "Luchs", "Lucia", "Lucie", "Lucky",
    "Lucys", "luden", "Luder", "ludet", "ludst", "Luegs", "Lugal", "lugen", "Luger", "lugst",
    "lugte", "Luigi", "Luisa", "Luise", "Lukas", "Luken", "Lukes", "Lulas", "lulle", "lullt",
    "Lumen", "Lumpi", "Lumps", "lunar", "Lunch", "Lunge", "Lunte", "Lupen", "lupfe", "lupft",
    "Lupos", "Lupus", "Lurch", "Luxor", "Luxus", "luzid", "Luzie", "Luzon", "Lydia", "Lynch",
    "Lynns", "Lyons", "Lyrik", "Lysin", "Maare", "Macao", "Macau", "mache", "Macho", "Machs",
    "macht", "Macke", "macOS", "Madam", "Maden", "madig", "Mafia", "Magda", "Magen", "mager",
    "Maggi", "Magie", "Magma", "magna", "magst", "Magus", "Mahdi", "mahle", "Mahls", "mahlt",
    "mahne", "mahnt", "Maier", "Maike", "Maiks", "maile", "Mails", "mailt", "Maine", "Mains",
    "Mainz", "Majas", "Major", "Makel", "Makis", "Makro", "malen", "Maler", "Malis", "Malls",
    "malme", "malmt", "malst", "Malta", "malte", "Malus", "Malva", "Malve", "Mamas", "Mamba",
    "Mambo", "Mamis", "mampf", "manch", "Mandy", "Manga", "Mango", "Manie", "Manko", "Manna",
    "Manne", "Manns", "Manon", "Manta", "Maori", "Mappe", "Maras", "Marco", "Marcs", "Marek",
    "Maren", "Marga", "Marge", "Maria", "Marie", "Marik", "marin", "Mario", "Marke", "Marko",
    "Marks", "Markt", "Marls", "Marne", "Marta", "Marys", "Maske", "Massa", "Masse", "Masud",
    "Masut", "Match", "mater", "Mathe", "matte", "mauem", "mauen", "mauer", "maues", "Mauke",
    "maule", "Mauls", "mault", "Maure", "mause", "maust", "mauve", "Maxim", "Mayas", "Mayen",
    "Mayer", "Mayrs", "Mazda", "MByte", "McCay", "McCoy", "McKay", "Mecki", "Medea", "Media",
    "Meere", "Meers", "Mehle", "Mehls", "mehre", "mehrt", "meide", "Meier", "Meike", "Meile",
    "meine", "meins", "meint", "Meise", "meist", "Mekka", "Melba", "melde", "melke", "melkt",
    "Melos", "Memel", "Memen", "Memme", "menge", "mengt", "Mensa", "Meran", "merci", "Merck",
    "merke", "merkt", "Merle", "merze", "merzt", "messe", "messt", "Mesut", "Meter", "Metro",
    "Mette", "Metze", "Meute", "Meyer", "Miami", "miaue", "miaut", "Micha", "Micks", "Micky",
    "Midas", "Miefs", "mieft", "Miele", "Miene", "miese", "miete", "Mieze", "Mikes", "Mikro",
    "Mikwe", "Milan", "Milas", "Milbe", "Milch", "milde", "Milet", "Miliz", "Milka", "Mille",
    "Milos", "Milva", "mimen", "Mimik", "mimte", "Minas", "Minen", "Mings", "Minis", "Minna",
    "Minne", "Minos", "Minsk", "minus", "Minze", "Miras", "Mirko", "Mirow", "misch", "misse",
    "misst", "miste", "Mitau", "Mitra", "Mitte", "mixed", "mixen", "Mixer", "mixte", "mobbt",
    "mobil", "modal", "Model", "Modem", "Moden", "Moder", "modre", "Modul", "Modus", "Moers",
    "Mofas", "mogle", "Mogli", "Mogul", "Mohns", "Mokka", "molar", "Molch", "Molen", "Molke",
    "Molli", "Molly", "Momos", "Monat", "Monde", "Monet", "Monis", "Monte", "Monty", "Moody",
    "Moore", "Moors", "Moose", "Moped", "Mopps", "Moral", "morde", "Mords", "Mores", "Morph",
    "morse", "Morus", "Mosel", "Moser", "Moses", "Mosts", "Motel", "Motiv", "Motor", "Motte",
    "Motto", "motze", "motzt", "Mount", "Movie", "MSDOS", "mtDNA", "mucke", "Mucki", "Mucks",
    "muckt", "Mudau", "Muffe", "Mufti", "muhen", "Mulch", "Mulde", "Mulis", "Multi", "Mumie",
    "Mumms", "Mumps", "munde", "Murat", "Murau", "Murks", "murre", "murrt", "Musau", "Musen",
    "musig", "Musik", "Musil", "musst", "muten", "Mutes", "mutet", "mutig", "Mutti", "myope",
    "Myrte", "MySQL", "Myzel", "Nabel", "Naben", "Nabob", "Nacht", "nackt", "Nadel", "Nadir",
    "Nadja", "Nagel", "nagen", "Nager", "nagle", "nagst", "nagte", "nahem", "nahen", "naher",
    "nahes", "nahmt", "nahst", "nahte", "naive", "Namen", "Namib", "Namur", "Nancy", "Nandu",
    "Nanny", "Naomi", "Napfs", "Nappa", "Narbe", "narre", "narrt", "Narva", "nasal", "Nasen",
    "nasse", "natal", "nativ", "Natur", "Nauen", "Nauru", "Navis", "Naxos", "Nazca", "Nazis",
    "Nebel", "neben", "Nebra", "nebst", "necke", "neckt", "Neffe", "Neger", "Negev", "Negro",
    "nehme", "nehmt", "Nehru", "neide", "Neids", "neige", "neigt", "Neill", "Neins", "Nelke",
    "Nelly", "nenne", "nennt", "Neons", "Nepal", "neppe", "Nepps", "neppt", "Nerds", "Neros",
    "nerve", "Nervs", "nervt", "Nerze", "Nests", "nette", "netto", "Netze", "neuem", "neuen",
    "neuer", "neues", "Neune", "neunt", "Neuss", "Nexus", "nicht", "nicke", "Nicki", "Nicks",
    "nickt", "Nicky", "Nidda", "Niels", "Niere", "Niers", "niese", "niest", "niete", "Nigel",
    "Niger", "Nikes", "Nikon", "Nikos", "nimmt", "Ninas", "Ninja", "Niobs", "nippe", "nippt",
    "Nisse", "niste", "Nivea", "Nixen", "Nixon", "Nizza", "Noahs", "nobel", "noble", "Nocke",
    "Nokia", "Nolde", "Nolte", "Nomen", "Nonne", "Noppe", "Norah", "Noras", "Norma", "norme",
    "North", "Notar", "Noten", "Notiz", "Notre", "Novum", "Nowak", "NSDAP", "Nubuk", "Nudel",
    "Nugat", "Nulpe", "Numen", "Nuten", "Nutte", "nutze", "nutzt", "Nylon", "Oasen", "Obama",
    "obere", "Obers", "Obhut", "obige", "oblag", "Oboen", "Ochse", "Ocken", "ocker", "Odems",
    "Odeon", "Odeur", "Odins", "Odium", "Oelde", "Ofens", "offen", "Oheim", "Ohios", "Ohren",
    "Ohres", "Okapi", "oktal", "Oktan", "Oktav", "Olafs", "Oldie", "Olegs", "Oleum", "Olgas",
    "olive", "ollem", "ollen", "oller", "olles", "Olmen", "Olmes", "Olper", "Olpes", "Olsen",
    "Olten", "Olymp", "Omaha", "Omama", "Omans", "omega", "Omens", "Onkel", "Onyxe", "opake",
    "Opale", "Opapa", "Opels", "Opera", "Opern", "opfer", "opfre", "Opiat", "Opitz", "Opium",
    "Optik", "orale", "Orang", "Orbis", "Orbit", "Orcas", "Ordal", "Orden", "Order", "ordne",
    "ordre", "Orffs", "Organ", "Orgel", "Orgie", "Orion", "Orkan", "Orkus", "Orlog", "Ornat",
    "orten", "Ortes", "ortet", "Osaka", "Osama", "Oscar", "Oschi", "Oskar", "Oslos", "Osman",
    "Osram", "Ossis", "Ostau", "Osten", "Ostia", "Otmar", "Otter", "Ottos", "outen", "outet",
    "ovale", "Ovals", "Ovids", "Owens", "Oxfam", "Oxide", "Oxids", "Oxyde", "Oybin", "Ozean",
    "Ozons", "paare", "Paars", "paart", "Pablo", "Pacht", "packe", "Packs", "packt", "Paddy",
    "Padua", "paffe", "pafft", "pagan", "Pagen", "Paket", "Pakte", "Pakts", "Palau", "Palma",
    "Palme", "Palms", "Pamir", "Pampa", "Pampe", "Pamps", "Panda", "Panik", "Panne", "Paola",
    "Paolo", "Papas", "Papen", "Paper", "pappe", "pappt", "Papst", "Papua", "parat", "Paria",
    "Paris", "Parka", "parke", "Parks", "parkt", "Parma", "Parse", "Parte", "Parts", "Party",
    "Parze", "Pasch", "Passa", "passe", "passt", "Pasta", "Paste", "Patch", "Paten", "Pater",
    "Patin", "Patio", "Patte", "Patts", "patze", "patzt", "pauke", "paukt", "Paula", "Pauli",
    "Paulo", "Pauls", "Pauly", "pause", "paust", "Pavia", "Pawel", "Peaks", "Pearl", "Pechs",
    "Pedal", "Pedro", "Peene", "Peers", "Pegel", "Peggy", "peile", "peilt", "Peine", "pelle",
    "pellt", "Pelze", "Penes", "Penis", "penne", "pennt", "Penny", "peppe", "peppt", "Pepsi",
    "Percy", "perdu", "perle", "perlt", "Perry", "Perth", "Perus", "Pesos", "Pesto", "Peter",
    "Petit", "Petra", "Petri", "Petry", "petto", "petze", "petzt", "Pfade", "Pfads", "Pfahl",
    "Pfalz", "Pfand", "Pfaue", "Pfaus", "Pfeil", "Pferd", "pfiff", "Pflug", "Pfote", "Pfuhl",
    "Pfund", "Phase", "phatt", "Phlox", "Phnom", "Phyla", "Phyle", "piano", "Piave", "picke",
    "pickt", "Pieck", "piepe", "Pieps", "piept", "Piero", "Piers", "Piezo", "Pikee", "piken",
    "pikse", "pikst", "pikte", "Pille", "Pilot", "Pilze", "pimpe", "Pimpf", "pimpt", "pinge",
    "Pings", "pingt", "Pinie", "pinke", "pinne", "pinnt", "Pinot", "Pinte", "Pinus", "Piotr",
    "Piper", "Pippi", "Pirat", "Pirna", "Pirol", "Pisas", "pisse", "pisst", "Piste", "Pixar",
    "Pixel", "Pizza", "Pjotr", "plage", "plagt", "Plaid", "plane", "Plans", "plant", "Plato",
    "platt", "Platz", "Playa", "Plaza", "Plebs", "Plena", "Plins", "plopp", "Plots", "Plugs",
    "plump", "Pluto", "Pneus", "poche", "pocht", "Pocke", "Podex", "Poems", "pofen", "pofst",
    "pofte", "Point", "Pokal", "Poker", "polar", "Poldi", "polen", "polig", "Polin", "Polio",
    "Polis", "Polka", "Polle", "Polly", "Polos", "polst", "polte", "Polyp", "Pomps", "Ponte",
    "Ponys", "Ponzi", "poole", "Pools", "poolt", "Popel", "Popen", "Popos", "poppe", "poppt",
    "Poren", "Porno", "Porta", "Porti", "Porto", "Ports", "Posen", "Posex", "POSIX", "Posse",
    "poste", "Posts", "Potis", "Potte", "Potts", "Power", "Prada", "Prado", "Prags", "Praha",
    "prall", "preis", "Priel", "Priem", "Prien", "pries", "prima", "Prime", "print", "Prinz",
    "Prior", "Prise", "PRISM", "Prius", "PRler", "probe", "probt", "Profi", "Prolo", "Promi",
    "Prosa", "prost", "Protz", "Proxy", "Prunk", "Psalm", "Pucks", "Pudel", "Puder", "pudre",
    "Puffs", "pulen", "Pulke", "Pulks", "pulle", "Pulli", "pullt", "Pulpa", "Pulpe", "pulse",
    "pulst", "pulte", "Pults", "Pumas", "pumpe", "Pumps", "pumpt", "Punks", "Punkt", "Punze",
    "Puppe", "pupse", "pupst", "purem", "puren", "purer", "pures", "Purim", "Purin", "pushe",
    "pusht", "Pussy", "puste", "Puten", "Puter", "Putin", "Putte", "Putto", "putze", "putzt",
    "Pylon", "Pyrit", "Qaida", "Qatar", "Quads", "Quais", "quake", "quakt", "Quali", "Qualm",
    "Quant", "Quark", "Quart", "Quarz", "quasi", "Quast", "Queen", "Quell", "quere", "quert",
    "Quest", "Queue", "Quick", "quill", "Quinn", "Quint", "Quirl", "Quito", "quitt", "quoll",
    "Quota", "Quote", "Rabat", "Rabbi", "Raben", "Rache", "Radar", "Radau", "Radek", "Rades",
    "Radio", "Radix", "radle", "Radom", "Radon", "raffe", "rafft", "ragen", "ragst", "ragte",
    "Rahel", "Rahen", "Rahms", "rahmt", "Raine", "Rains", "Rakel", "Ralfs", "Ralle", "Ralph",
    "Rambo", "ramme", "rammt", "Ramon", "Rampe", "Ranch", "Rande", "Randy", "Ranft", "Range",
    "Rangs", "rangt", "ranke", "rankt", "Ranze", "Raoul", "rapid", "Rappe", "rappt", "rarem",
    "raren", "rarer", "rares", "rasch", "rasen", "Raser", "Rasse", "raste", "Rasur", "raten",
    "Rates", "ratet", "ratio", "Ratte", "ratze", "ratzt", "raube", "Raubs", "raubt", "rauch",
    "Raudi", "rauem", "rauen", "rauer", "raues", "raufe", "rauft", "Rauke", "Raume", "Raums",
    "raune", "raunt", "Raupe", "raust", "raute", "Ravel", "Raver", "Rayon", "reale", "Realo",
    "Reben", "Rebus", "reche", "recht", "recke", "reckt", "recto", "reden", "redet", "Reede",
    "reell", "Reepe", "Reeps", "reffe", "refft", "Regal", "Regel", "regem", "regen", "reger",
    "reges", "Regex", "Regie", "regle", "regne", "regst", "regte", "Rehau", "Rehen", "reibe",
    "reibt", "reich", "reife", "Reifs", "reift", "reihe", "reiht", "Reiki", "reime", "Reims",
    "reimt", "reine", "reise", "reist", "reite", "reize", "reizt", "rekle", "relax", "remis",
    "Remix", "Remus", "renal", "renke", "renkt", "renne", "rennt", "Rente", "Rerum", "Resch",
    "Reset", "Reste", "Rests", "retro", "rette", "reuen", "reuig", "Reuse", "Reuss", "reute",
    "Reval", "Revue", "Rewes", "Rheda", "Rhein", "Rhema", "Rhode", "Rhone", "Riads", "Ricas",
    "Richy", "Ricke", "Ricky", "Ricos", "riebe", "riebt", "riech", "riefe", "rieft", "Riege",
    "Riehl", "Riesa", "Riese", "riete", "Riffe", "Riffs", "Rigas", "Rigor", "Rilke", "Rille",
    "Rinde", "Rinds", "ringe", "Ringo", "rings", "ringt", "rinne", "rinnt", "Rioja", "Rippe",
    "Rispe", "Risse", "risst", "Ritas", "Riten", "ritte", "Ritts", "Ritus", "ritze", "ritzt",
    "River", "robbe", "robbt", "Roben", "Robin", "Robot", "rocht", "rocke", "Rocks", "rockt",
    "Rocky", "Rodel", "roden", "Rodeo", "rodet", "Rodin", "rodle", "Rogen", "Roger", "Rohei",
    "rohem", "rohen", "roher", "rohes", "Rohre", "Rohrs", "Rolex", "Rolfs", "rolle", "Rolli",
    "Rollo", "Rolls", "rollt", "Roman", "Romeo", "Romys", "Ronde", "Rondo", "Ronja", "Ronny",
    "Rosas", "Rosen", "Roses", "Rosie", "rosig", "Rosis", "Rosse", "Rossi", "roste", "rotem",
    "roten", "roter", "rotes", "Rothe", "Rotor", "rotte", "rotze", "rotzt", "Rouen", "Rouge",
    "Route", "Rover", "Rowdy", "royal", "Royce", "Rubel", "Rubin", "Rubra", "rucke", "Rucks",
    "ruckt", "Rudel", "Ruder", "Rudis", "Rudys", "rufen", "Rufer", "Rufes", "rufst", "Rufus",
    "Rugby", "ruhen", "ruhig", "Ruhla", "Ruhms", "ruhst", "ruhte", "Ruine", "Ruins", "Rumba",
    "Rumor", "Rumpf", "rumse", "rumst", "runde", "Runen", "Runge", "rupfe", "rupft", "Rupie",
    "Ruppe", "rural", "Rushs", "Russe", "Ruten", "Ruths", "Rutte", "Ruwer", "Saale", "Saals",
    "Sache", "Sachs", "sacht", "sacke", "Sacks", "sackt", "Safes", "safte", "Safts", "sagen",
    "Sager", "sagst", "sagte", "Sahel", "sahen", "Sahib", "sahne", "sahnt", "sahst", "Saint",
    "Saite", "Sakko", "Sakra", "Salam", "Salat", "salbe", "salbt", "Saldo", "Salem", "Sally",
    "Salon", "Salsa", "Salto", "Salut", "Salve", "salze", "salzt", "Samba", "Samen", "Sammy",
    "Samoa", "Samos", "Samts", "Sanaa", "Sande", "Sands", "Sandy", "sanft", "sangt", "sankt",
    "sannt", "Santa", "Santo", "Sanyo", "Sarah", "Saras", "Sarde", "Sargs", "Sarin", "Saris",
    "Sasse", "Satan", "Satin", "satte", "Satyr", "Satze", "Sauce", "saudi", "sauen", "sauer",
    "saufe", "sauft", "sauge", "saugt", "Sauls", "Saums", "Sauna", "saure", "sause", "saust",
    "saute", "Savoy", "Scala", "Scans", "schab", "Schaf", "Schah", "schal", "Scham", "Schar",
    "schau", "scher", "scheu", "Schia", "Schis", "Schmu", "schob", "schon", "schor", "Schot",
    "Schub", "schuf", "Schuh", "Schur", "Score", "Scott", "Scout", "SEATO", "secco", "sechs",
    "Sedan", "Seele", "Segel", "Segen", "Segge", "segle", "segne", "sehen", "Seher", "sehne",
    "sehnt", "Seide", "seien", "seife", "seift", "Seiko", "seile", "Seils", "seilt", "seine",
    "seins", "seist", "Seite", "Sekte", "Sekts", "selbe", "Selen", "selig", "Selim", "Selma",
    "Semem", "Semit", "Senat", "sende", "Senfs", "senge", "sengt", "senil", "senke", "senkt",
    "Senne", "Sense", "Senta", "Seoul", "Sepia", "Sepps", "Serbe", "Seren", "Serge", "Serie",
    "Serin", "Serra", "Serum", "Sesam", "Setup", "setze", "setzt", "seufz", "Sexes", "Sexta",
    "Sexte", "Sexus", "Shake", "Sharp", "Shaws", "Shell", "Shift", "Shirt", "Shiva", "Shoah",
    "Shops", "Shows", "Siams", "Sibiu", "Sicht", "Sicke", "Sidon", "siebe", "Siebs", "siebt",
    "siech", "siede", "siege", "Siegs", "siegt", "siehe", "sieht", "Siele", "Siels", "Siena",
    "sieze", "siezt", "Sigel", "Siggi", "Sigis", "Sigle", "sigma", "Sikhs", "Silbe", "Silke",
    "Silos", "Silur", "Simon", "Simse", "Sinai", "singe", "singt", "sinke", "sinkt", "sinne",
    "Sinns", "sinnt", "Sinti", "Sinus", "Sioux", "Sippe", "SIPRI", "Sirup", "Sisal", "Sissi",
    "Sissy", "Sitar", "Sites", "Sitte", "sitze", "sitzt", "Skala", "Skalp", "skate", "Skats",
    "Skier", "Skill", "Skins", "Skoda", "Skunk", "Skype", "skypt", "Slang", "Slawe", "Slick",
    "Slips", "Slots", "Slums", "smart", "Smith", "Smogs", "Snack", "Snobs", "Soaps", "Socke",
    "Sodas", "Soden", "Sodom", "Soest", "Sofas", "sofft", "Sofia", "Sofie", "softe", "sogar",
    "sogen", "Soges", "sogst", "Sohle", "Sohne", "Sohns", "Sojus", "solar", "solch", "Solde",
    "Solds", "Solei", "Solen", "Solid", "solle", "sollt", "Solon", "Solos", "somit", "Somme",
    "Sonar", "Sonde", "Songs", "Sonia", "Sonja", "sonne", "sonnt", "sonor", "sonst", "Sonys",
    "sooft", "Sopor", "Sorbe", "sorge", "sorgt", "sorry", "Sorte", "Souks", "Sound", "South",
    "sowie", "Sozis", "Space", "Spalt", "spann", "Spans", "Spant", "SPARC", "spare", "spart",
    "Spatz", "Speck", "Speed", "Speer", "speie", "speit", "Spelz", "sperr", "Spezi", "Spice",
    "spiel", "spien", "spiet", "Spike", "Spill", "Spina", "Spind", "spinn", "Spins", "Spion",
    "spitz", "Split", "Spock", "Spore", "Sporn", "Sport", "Spots", "Spott", "Spray", "Spree",
    "Spreu", "Sprit", "spuck", "spuke", "Spuks", "spukt", "spule", "spult", "Spund", "Spurt",
    "spute", "SpVgg", "Squaw", "Staat", "Stabs", "stach", "Stack", "Stade", "Stadt", "Stage",
    "stahl", "stakt", "Stall", "Stamm", "stand", "stank", "starb", "Stare", "stark", "starr",
    "Stars", "Start", "Stasi", "statt", "Staub", "staue", "Staus", "staut", "Steak", "Steam",
    "steck", "Stege", "Stegs", "stehe", "steht", "steif", "steig", "steil", "Stein", "Stele",
    "stell", "Steno", "Stenz", "Stern", "Sterz", "stete", "Stetl", "stets", "Steve", "Stews",
    "Steyr", "stich", "Stick", "stieg", "Stiel", "Stier", "Stift", "Stile", "still", "Stils",
    "Stino", "Stipp", "stirb", "Stirn", "Stock", "Stoff", "Stola", "stolz", "Stone", "stopf",
    "stopp", "Store", "Storm", "Story", "Streb", "streu", "Strip", "Stroh", "Strom", "Stube",
    "Stuck", "Studi", "stufe", "stuft", "Stuhl", "Stuka", "stumm", "Stunk", "Stunt", "Stupa",
    "Stups", "sture", "Sturm", "Sturz", "Stuss", "Stute", "StVZO", "style", "stylt", "Suada",
    "Suade", "suche", "sucht", "Sudan", "sudle", "Sufis", "suhle", "suhlt", "Suite", "Sujet",
    "Sulky", "Sulla", "sulze", "sulzt", "Sumer", "summa", "summe", "summt", "Sumpf", "Suomi",
    "super", "Suppe", "Supra", "Suren", "surfe", "surft", "surre", "surrt", "Susan", "Sushi",
    "Susie", "Susis", "Suzys", "Svens", "Sveta", "SWAPO", "Swift", "Swing", "Swiss", "Syene",
    "Syker", "Sykes", "Sylts", "Syrer", "Syrte", "Szene", "Tabak", "Tabea", "Tabor", "Tabus",
    "Tacho", "Tacos", "Tadel", "tadle", "Tafel", "tafle", "Tafts", "tagen", "Tages", "tagge",
    "taggt", "tagst", "tagte", "Taiga", "Takel", "takle", "takte", "Takts", "Talar", "Taler",
    "Tales", "Talgs", "Talks", "Talon", "Talus", "Tamil", "Tands", "Tanga", "Tango", "Tangs",
    "Tanja", "tanke", "Tanks", "tankt", "Tanne", "Tante", "tanze", "tanzt", "Tapas", "Tapes",
    "Tapet", "Tapir", "tappe", "tappt", "tapse", "tapst", "Tarif", "tarne", "tarnt", "Tarot",
    "Tarps", "Tartu", "Taser", "Tasks", "Tasse", "Tasso", "taste", "Tatar", "taten", "tatet",
    "Tatra", "tatst", "Tatze", "taube", "tauen", "Taues", "taufe", "tauft", "tauge", "taugt",
    "taust", "taute", "Taxen", "Taxis", "Taxon", "Taxus", "TByte", "Teams", "Teddy", "Teeei",
    "Teens", "Teeny", "teere", "Teers", "teert", "Tegel", "Teich", "Teige", "Teigs", "teile",
    "teils", "teilt", "Teins", "Teint", "Telex", "Telko", "Tells", "Tempi", "Tempo", "Tenne",
    "Tenno", "Tenor", "Terme", "Terms", "Terra", "Terry", "Tesla", "Tessa", "teste", "Tests",
    "Tetum", "teuer", "Teufe", "teure", "Texas", "Texel", "texte", "Texts", "Thais", "Thein",
    "Theke", "Thema", "Theos", "These", "theta", "Thiel", "Thilo", "Thing", "Thora", "Thorn",
    "Thors", "Thron", "Thuje", "Thule", "Thurn", "Tiara", "Tiber", "Tibet", "ticke", "Ticks",
    "tickt", "Tiden", "Tieck", "tiefe", "Tiefs", "Tiere", "Tiers", "Tietz", "Tiger", "Tilde",
    "tilge", "tilgt", "Tilia", "Tills", "Tilly", "timen", "Timer", "Times", "Timex", "Timms",
    "Timmy", "Timor", "Timur", "Tinas", "Tinte", "Tipis", "tippe", "Tipps", "tippt", "Tiran",
    "Tirol", "Tisch", "Titan", "Titel", "Titer", "Titos", "Titte", "Titus", "Toast", "Tobak",
    "toben", "Tobis", "tobst", "tobte", "Toddy", "Toden", "Todes", "Tofus", "Togen", "Togos",
    "token", "Tokio", "Tokyo", "tolle", "tollt", "Tommi", "Tommy", "Tomsk", "tonal", "Tonen",
    "Toner", "Tones", "Tonga", "Tonic", "tonig", "Tonis", "Tonne", "Tonus", "Tools", "Topas",
    "Topfs", "Topik", "Topoi", "Topos", "toppt", "Toren", "Tores", "Torfe", "Torfs", "Torso",
    "Torte", "Torus", "Tosca", "tosen", "toste", "total", "totem", "toten", "toter", "totes",
    "Totos", "Touch", "tough", "Touri", "Tours", "tourt", "Tower", "Toxin", "trabe", "Trabi",
    "trabt", "Track", "Tracy", "Trade", "Trafo", "traft", "trage", "tragt", "Trail", "Trakl",
    "Trakt", "tramp", "Trams", "Trane", "trank", "Trans", "Trapp", "Trara", "Trash", "traue",
    "Traum", "Traun", "traut", "Trebe", "Treck", "Treff", "treib", "Trema", "Trend", "trete",
    "treue", "Trias", "Trick", "trieb", "Trier", "triff", "Trift", "Trike", "trink", "Trios",
    "Trips", "trist", "tritt", "tRNAs", "Troas", "Troer", "troff", "trogt", "Troja", "Troll",
    "Tropf", "Tross", "Trost", "Trott", "trotz", "Truck", "Trude", "Trudi", "trugt", "Truhe",
    "Trumm", "Trump", "Trunk", "Trupp", "Trust", "Tuben", "Tubus", "Tuche", "Tuchs", "Tudor",
    "tuend", "Tuffe", "Tuffs", "Tukan", "Tulpe", "tumbe", "Tumor", "tunen", "Tuner", "Tunis",
    "tunke", "tunkt", "tunst", "Tunte", "Tupel", "tupfe", "tupft", "Turbo", "Turin", "Turku",
    "Turme", "Turms", "turne", "turnt", "Tusch", "Tusse", "Tussi", "tuten", "tutet", "Tutor",
    "Tutsi", "tutti", "Tutus", "Twain", "Tweed", "Tweet", "Twens", "Twist", "Tyler", "Tylom",
    "Typen", "Typik", "Typus", "Tyros", "Tyrus", "Tyson", "TzBfG", "Ubier", "Uchta", "Udine",
    "UdSSR", "Uedem", "ufere", "ufern", "Ufers", "ufert", "UFRGS", "Uhren", "ulken", "ulkig",
    "ulkst", "ulkte", "Ulkus", "Ullas", "Ulmen", "Ulmer", "ultra", "Umbau", "Umber", "umbog",
    "Umbra", "umgab", "umher", "umhin", "umkam", "umlud", "umsah", "umtue", "umtun", "umtut",
    "Umweg", "umzog", "Umzug", "Unart", "unbar", "UNDCP", "Unfug", "Ungar", "ungut", "UNHCR",
    "Union", "UNITA", "Units", "Unkel", "unken", "unkst", "unkte", "Unmut", "Unnas", "Unrat",
    "Unruh", "unser", "Untat", "unten", "unter", "untot", "Unzen", "Urahn", "Urals", "uralt",
    "Urans", "urban", "urbar", "UrhWG", "Uriel", "urige", "Urins", "Urnen", "Uroma", "Uropa",
    "Ursel", "Ursus", "Urtyp", "USAAF", "Usanz", "Uschi", "Usern", "Users", "Usutu", "Utahs",
    "Utans", "Uteri", "Uvula", "vadis", "Vaduz", "vagem", "vagen", "vager", "vages", "Valin",
    "Vamps", "Varia", "Varix", "VARTA", "Varus", "Vasco", "Vasen", "Vater", "Vatis", "vegan",
    "Vegas", "Veith", "Veits", "velar", "Velin", "Venen", "Venia", "Venlo", "Venns", "Venus",
    "Veras", "Verbs", "Verdi", "vergl", "Verse", "Verve", "Vespa", "Vesta", "Vesuv", "Vetos",
    "Vichy", "Vicki", "Vicky", "Video", "Viech", "Viehs", "viele", "Viere", "viert", "Vigil",
    "Vikar", "Villa", "Ville", "Vince", "Vinci", "Vinyl", "Viola", "Viole", "Viper", "viral",
    "Viren", "Virgo", "viril", "Virus", "Visio", "Visit", "vista", "Visum", "Visus", "vitae",
    "vital", "Viten", "vitro", "Vitus", "Vlies", "Vogel", "Vogts", "vogue", "Voigt", "Voile",
    "vokal", "volar", "Volke", "Volks", "volle", "Volos", "Volta", "Volte", "Volvo", "Vopos",
    "vorab", "voran", "vorne", "Voten", "Votum", "vulgo", "Vulva", "VwVfG", "Waadt", "Waage",
    "Waben", "wache", "Wachs", "wacht", "Waden", "Wadis", "Waffe", "wagen", "Wagon", "wagst",
    "wagte", "Wahns", "wahre", "wahrt", "Waise", "Walch", "Walde", "Waldi", "Waldo", "Walen",
    "Wales", "walke", "walkt", "walle", "Walls", "wallt", "Wally", "walte", "walze", "walzt",
    "Wampe", "Wanda", "Wange", "wanke", "wankt", "Wanne", "Wanst", "Wanze", "Waran", "warbt",
    "waren", "warft", "warme", "Warna", "warne", "warnt", "warst", "warte", "warum", "Warze",
    "wasch", "waten", "watet", "Watte", "Watts", "Wayne", "weben", "Weber", "WebEx", "webOS",
    "webst", "webte", "wecke", "weckt", "Wedel", "weder", "wedle", "Weeze", "wegen", "Weges",
    "wehen", "wehre", "Wehrs", "wehrt", "wehst", "wehte", "Weibe", "weich", "Weida", "weide",
    "weihe", "weiht", "weile", "Weill", "weilt", "weine", "Weins", "weint", "weise", "weist",
    "weite", "welch", "Welfe", "welke", "welkt", "welle", "wellt", "Welpe", "Welse", "wende",
    "Wendy", "wenig", "werbe", "werbt", "werde", "werfe", "werft", "werke", "Werks", "werkt",
    "Werra", "Werst", "werte", "Werts", "Wesel", "Wesen", "Weser", "Wesir", "Wespe", "Wessi",
    "Weste", "wette", "wetze", "wetzt", "Weyer", "Whigs", "White", "Wibke", "wiche", "wichs",
    "wicht", "Wicke", "wider", "widme", "widre", "Wieck", "wiege", "wiegt", "Wiehl", "Wiens",
    "wiese", "Wiesn", "wieso", "wiest", "Wikis", "wilde", "Wilds", "Wille", "Willi", "Willy",
    "Wilma", "Wilms", "Wilna", "winde", "Winds", "Wings", "winke", "Winks", "winkt", "wippe",
    "wippt", "wirbt", "wirft", "wirke", "wirkt", "wirre", "wirrt", "wirst", "Wirte", "Wirts",
    "wisch", "wisse", "wisst", "Witwe", "Witze", "wobei", "woben", "wobst", "Woche", "Wodka",
    "wogen", "wogst", "wogte", "woher", "wohin", "Wohle", "Wohls", "wohne", "wohnt", "Wolff",
    "Wolfs", "Wolga", "Wolke", "wolle", "wollt", "womit", "Wonne", "Woods", "Woody", "woran",
    "worin", "World", "Worms", "Worte", "Worts", "worum", "Wotan", "wovon", "wovor", "Wrack",
    "wrang", "Wraps", "Wruke", "wuchs", "Wucht", "Wuhan", "Wulff", "Wulst", "Wumme", "wumpe",
    "wunde", "wuppe", "wuppt", "wurde", "Wurfs", "wurme", "Wurms", "wurmt", "Wurst", "wusch",
    "wusle", "Wusts", "Xaver", "Xenia", "Xenie", "Xenix", "Xenon", "Xerox", "Xetra", "Xhosa",
    "XHTML", "XLIII", "XLVII", "XVIII", "XXIII", "XXVII", "XXXII", "XXXIV", "XXXIX", "XXXVI",
    "Xylit", "Xylol", "Yacht", "Yahoo", "Yards", "Yetis", "Ylang", "Yogas", "Yogis", "Yorck",
    "Yorks", "Young", "Ypern", "Yucca", "Yukon", "Yusuf", "Zacke", "Zadek", "zagen", "zahle",
    "zahlt", "zahme", "zahne", "Zahns", "zahnt", "Zaire", "Zange", "zanke", "zankt", "zapfe",
    "zapft", "Zappa", "zappe", "zappt", "Zaras", "Zaren", "Zarge", "Zarin", "zarte", "Zaume",
    "Zaums", "Zauns", "zaust", "Zebra", "Zebus", "zeche", "zecht", "Zecke", "Zeder", "Zehen",
    "zehnt", "zehre", "zehrt", "zeige", "zeigt", "zeihe", "zeiht", "Zeile", "Zeiss", "Zeitz",
    "Zelle", "Zelot", "zelte", "Zelts", "Zenit", "Zenon", "Zenzi", "zerre", "zerrt", "Zeter",
    "zetre", "zeuge", "Zeugs", "zeugt", "zicke", "zickt", "Ziege", "ziehe", "zieht", "ziele",
    "Ziels", "zielt", "zieme", "ziemt", "ziept", "ziere", "ziert", "Zilie", "Zille", "Zilli",
    "Zimts", "zinke", "Zinks", "zinkt", "Zinne", "Zinns", "Zinse", "Zions", "zippe", "Zippo",
    "Zirbe", "zirka", "zirpe", "zirpt", "zisch", "Zitas", "Zitat", "Zitze", "zivil", "Zivis",
    "Zloty", "Zobel", "zockt", "Zofen", "zoffe", "zofft", "zogen", "zogst", "Zolas", "zolle",
    "Zolls", "zollt", "zonal", "Zonen", "zoome", "Zooms", "zoomt", "Zopfs", "Zorns", "Zorro",
    "Zosse", "Zoten", "zotig", "Zotte", "Zubau", "Zuber", "Zucht", "zucke", "zuckt", "zudem",
    "zugab", "Zuger", "Zuges", "zugig", "zukam", "Zulus", "zumal", "Zunft", "Zunge", "zupfe",
    "zupft", "zurre", "zurrt", "Zuruf", "zusah", "zutat", "zutun", "zutut", "zuvor", "zuzog",
    "Zuzug", "zwang", "Zweck", "Zweig", "zweit", "Zwerg", "zwick", "zwing", "Zwirn", "Zwist",
    "Zyste",
];
